{% extends base_change_list_template %}

{% block extrahead %}
	{{ block.super }}
	<script type="application/json" id="admin_sortable2_config">
		{
			"update_url": "{{ sortable_update_url }}",
			"current_page": {{ cl.page_num }},
			"total_pages": {{ cl.paginator.num_pages }}
		}
	</script>
{% endblock %}
